=========
Easy Menu
=========

Simplify Your Daily Terminal Operations.

.. image:: https://travis-ci.org/mogproject/easy-menu.svg?branch=v1.0
   :target: https://travis-ci.org/mogproject/easy-menu
   :alt: Build Status

.. image:: https://coveralls.io/repos/mogproject/easy-menu/badge.svg?branch=v1.0&service=github
   :target: https://coveralls.io/github/mogproject/easy-menu?branch=master
   :alt: Coverage Status

.. image:: https://img.shields.io/badge/license-Apache%202.0-blue.svg
   :target: http://choosealicense.com/licenses/apache-2.0/
   :alt: License

.. image:: https://badge.waffle.io/mogproject/easy-menu.svg?label=ready&title=Ready
   :target: https://waffle.io/mogproject/easy-menu
   :alt: 'Stories in Ready'

--------
Features
--------

Do you have any routine tasks such as login to your servers, deploying, troubleshooting or something like that?

This small tool would help to speed up your operations and prevent human errors.
It should be helpful not only for salted engineers but unskilled operators.

(todo) gif animation

------------
Dependencies
------------

* Python >= 2.6
* pyyaml

------------
Installation
------------

(todo)

---------------------
Configuration Example
---------------------

(todo)

Remember these commands are executed after changing the current directory to the directory which holds the configuration file.

-----------
Lookup Path
-----------

When you run `easy-menu` command, ...

- `easy-menu.yml` in the current directory.
- `easy-menu.json` in the current directory.
- `~/easy-menu.yml`
- `~/easy-menu.json`
- `/etc/easy-menu/easy-menu.yml`
- `/etc/easy-menu/easy-menu.json`

---------
Audit Log
---------

(todo)

-------
Example
-------

(todo)

